Hook to Event module
---------------------------

INTRODUCTION
-----------
This module is intended for the developers and allows them to
handle Drupal hooks in the event subscriber provided
by the Symfony framework.
All of the hooks in Drupal core that are invoked by the module handler
and by the theme handler (note: theme not yet implemented) can be now
registered in the subscriber by using the hook name.

INSTALLATION:
-------------
### Using composer:
```composer require drupal/hook_event```

REQUIREMENTS
------------
The minimum PHP supported version is 8.0.
We will also require Drupal 9 or higher.

CONFIGURATION
-------------
Does not require any configuration.

USAGE
-----
Define the new event subscriber in your custom module as you usually
do in the `my_module.services.yml` file.
Register the event by using the hook name.
Example: In order to subscribe for the `hook_entity_update` you'll
have to define in your subscriber:
```php
public static function getSubscribedEvents(): array {
  return [
    'hook_entity_update' => ['myEntityUpdateHandlerMethod', 0]
  ];
}
```
In your method definition you can interact with the event like this:
```php
public function myEntityUpdateHandlerMethod(\Drupal\hook_event\Event\HookInvokeEvent $event): void {
  // Accessing by argument name (if hook was registered).
  $entity = $event->getArgument('entity');
  // Accessing by argument position (if hook wasn't registered).
  $entity = $event->getArgument(0);
  // The logic goes here...

  // Apply the changes (useful for non object variables).
  $event->setArgument('entity', $entity);

  // Set return value in case the hook require some return.
  $event->setReturnValue([...]);
}

```

UNINSTALLATION
--------------
### Using composer:
```composer require remove/hook_event```

MAINTAINERS
-----------
Current maintainers:
* Mariusz Andrzejewski (sayco) - https://www.drupal.org/u/sayco
